California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 30 - 2000 REFERENDUM PETITION TO OVERTURN "THE FAIR INSURANCE RESPONSIBILITY ACT." View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991916 | CONSUMERS AND THEIR ATTORNEYS, YES ON PROPOSITION 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991908 | CONSUMERS AGAINST FRAUD AND HIGHER INSURANCE COSTS: NO ON 30 AND 31, SPONSORED BY CONSUMERS, TAXPAYERS, SENIORS, INSURERS, LAW ENFORCEMENT AND SMALL BUSINESSES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992147 | VOTER REVOLT COMMITTEE AGAINST PROPOSITIONS 30 AND 31, SPONSORED BY VOTER REVOLT AND CONSUMERS | OPPOSE